@@ -3,8 +3,6 @@ package IO::Framed::Read;
 use strict;
 use warnings;
 
-use IO::SigGuard ();
-
 use IO::Framed::X ();
 
 sub new {
@@ -28,8 +26,20 @@ sub get_read_fh { return $_[0]->{'_in_fh'} }
 #----------------------------------------------------------------------
 # IO subclass interface
 
+sub allow_empty_read {
+    my ($self) = @_;
+    $self->{'_ALLOW_EMPTY_READ'} = 1;
+    return $self;
+}
+
 my $buf_len;
 
+sub READ {
+    require IO::SigGuard;
+    *READ = *IO::SigGuard::sysread;
+    goto &READ;
+}
+
 #We assume here that whatever read may be incomplete at first
 #will eventually be repeated so that we can complete it. e.g.:
 #
@@ -55,12 +65,15 @@ sub read {
 
         local $!;
 
-        $bytes -= IO::SigGuard::sysread( $self->{'_in_fh'}, $self->{'_read_buffer'}, $bytes, $buf_len ) || do {
+        $bytes -= $self->can('READ')->( $self->{'_in_fh'}, $self->{'_read_buffer'}, $bytes, $buf_len ) || do {
             if ($!) {
                 if ( !$!{'EAGAIN'} && !$!{'EWOULDBLOCK'}) {
                     die IO::Framed::X->create( 'ReadError', $! );
                 }
             }
+            elsif ($self->{'_ALLOW_EMPTY_READ'}) {
+                return q<>;
+            }
             else {
                 die IO::Framed::X->create('EmptyRead');
             }
